=================
DJANGO ADMIN KUBI
=================

Supports Django 4.0+

Django admin Kubi applies a face lift for the Django admin interface and mechanics. Its features include:

* A fast, attractive editor interface
* Complete Bootstrap 5 Templates
* Sass support for custom styling
* Font awesome
* Mobile friendly
* TinyMce Widget
* Admin with sidebar menu for easy navigation
* Admin Search View
* Admin LogEntry view
* django-modeltranslation support
